@@ -1,5 +1,7 @@
-from .iai import _IAI, _requires_iai_version, _iai_version_less_than
+from .iai import (_IAI, _Main, _requires_iai_version, _iai_version_less_than,
+                  _get_learner_type)
 import warnings as _warnings
+import numpy as _np
 
 
 def split_data(*args, **kwargs):
@@ -7,7 +9,7 @@ def split_data(*args, **kwargs):
     `(X_train, y_train), (X_test, y_test)`, for a problem of type `task`.
 
     Julia Equivalent:
-    `IAI.split_data <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.split_data>`
+    `IAI.split_data <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.split_data>`
 
     Examples
     --------
@@ -20,7 +22,7 @@ def set_rich_output_param(*args, **kwargs):
     """Sets the global rich output parameter `key` to `value`.
 
     Julia Equivalent:
-    `IAI.set_rich_output_param! <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.set_rich_output_param!>`
+    `IAI.set_rich_output_param! <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.set_rich_output_param!>`
 
     Examples
     --------
@@ -33,7 +35,7 @@ def get_rich_output_params(*args, **kwargs):
     """Return the current global rich output parameter settings.
 
     Julia Equivalent:
-    `IAI.get_rich_output_params <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.get_rich_output_params>`
+    `IAI.get_rich_output_params <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.get_rich_output_params>`
 
     Examples
     --------
@@ -46,7 +48,7 @@ def delete_rich_output_param(*args, **kwargs):
     """Delete the global rich output parameter `key`.
 
     Julia Equivalent:
-    `IAI.delete_rich_output_param! <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.delete_rich_output_param!>`
+    `IAI.delete_rich_output_param! <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.delete_rich_output_param!>`
 
     Examples
     --------
@@ -55,6 +57,30 @@ def delete_rich_output_param(*args, **kwargs):
     return _IAI.delete_rich_output_param_convert(*args, **kwargs)
 
 
+def read_json(filename):
+    """Read in a learner or grid saved in JSON format from `filename`.
+
+    Julia Equivalent:
+    `IAI.read_json <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.read_json>`
+
+    Examples
+    --------
+    >>> read_json(filename)
+    """
+
+    jl_obj = _IAI.read_json_convert(filename)
+
+    if _Main.isa(jl_obj, _IAI.GridSearch):
+        lnr = _get_learner_type(_IAI.get_learner(jl_obj))()
+        grid = GridSearch(lnr)
+        grid._jl_obj = jl_obj
+        return grid
+    else:
+        lnr = _get_learner_type(jl_obj)()
+        Learner.__init__(lnr, jl_obj)
+        return lnr
+
+
 class Learner():
     """Abstract type encompassing all learners"""
     def __init__(self, jl_obj):
@@ -66,11 +92,22 @@ class Learner():
     def _repr_html_(self):
         return _IAI.to_html(self._jl_obj)
 
+    def __getstate__(self):
+        if isinstance(self, GridSearch):
+            _requires_iai_version("1.1.0", "pickle (for GridSearch)")
+        return {'_jl_obj_json': _IAI.to_json(self._jl_obj)}
+
+    def __setstate__(self, state):
+        self._jl_obj = _IAI.from_json(state['_jl_obj_json'])
+        if isinstance(self, GridSearch):
+            self._lnr_type = _get_learner_type(_IAI.get_learner(self._jl_obj))
+        return self
+
     def fit(self, *args, **kwargs):
         """Fit a model using the parameters in learner and the data `X` and `y`.
 
         Julia Equivalent:
-        `IAI.fit! <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.fit!>`
+        `IAI.fit! <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.fit!>`
 
         Examples
         --------
@@ -79,7 +116,7 @@ class Learner():
         Parameters
         ----------
         Refer to the documentation on
-        `data preparation <https://docs.interpretable.ai/v2.0.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
+        `data preparation <https://docs.interpretable.ai/v2.1.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
         for information on how to format and supply the data.
         """
         _IAI.fit_convert(self._jl_obj, *args, **kwargs)
@@ -89,7 +126,7 @@ class Learner():
         """Write learner or grid to `filename` in JSON format.
 
         Julia Equivalent:
-        `IAI.write_json <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.write_json>`
+        `IAI.write_json <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.write_json>`
 
         Examples
         --------
@@ -104,7 +141,7 @@ class Learner():
         """Return the value of all learner parameters.
 
         Julia Equivalent:
-        `IAI.get_params <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.get_params>`
+        `IAI.get_params <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.get_params>`
 
         Examples
         --------
@@ -119,7 +156,7 @@ class Learner():
         """Set all supplied parameters on learner.
 
         Julia Equivalent:
-        `IAI.set_params! <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.set_params!>`
+        `IAI.set_params! <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.set_params!>`
 
         Examples
         --------
@@ -135,7 +172,7 @@ class Learner():
         """Return an unfitted copy of the learner with the same parameters.
 
         Julia Equivalent:
-        `IAI.clone <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.clone>`
+        `IAI.clone <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.clone>`
 
         Examples
         --------
@@ -159,7 +196,7 @@ class SupervisedLearner(Learner):
         features `X`.
 
         Julia Equivalent:
-        `IAI.predict <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.predict>`
+        `IAI.predict <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.predict>`
 
         Examples
         --------
@@ -171,7 +208,7 @@ class SupervisedLearner(Learner):
         """Calculates the score for the learner on data `X` and `y`.
 
         Julia Equivalent:
-        `IAI.score <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.score>`
+        `IAI.score <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.score>`
 
         Examples
         --------
@@ -185,7 +222,7 @@ class SupervisedLearner(Learner):
         they sum to one.
 
         Julia Equivalent:
-        `IAI.variable_importance <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.variable_importance>`
+        `IAI.variable_importance <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.variable_importance>`
 
         Examples
         --------
@@ -207,7 +244,7 @@ class ClassificationLearner(SupervisedLearner):
         learner for each point in the features `X`.
 
         Julia Equivalent:
-        `IAI.predict_proba <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.predict_proba>`
+        `IAI.predict_proba <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.predict_proba>`
 
         Examples
         --------
@@ -233,7 +270,7 @@ class SurvivalLearner(SupervisedLearner):
         each point in the data `X`.
 
         Julia Equivalent:
-        `IAI.predict_expected_survival_time <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.predict_expected_survival_time>`
+        `IAI.predict_expected_survival_time <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.predict_expected_survival_time>`
 
         Examples
         --------
@@ -255,7 +292,7 @@ class SurvivalLearner(SupervisedLearner):
         survival time.
 
         Julia Equivalent:
-        `IAI.predict_hazard <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.predict_hazard>`
+        `IAI.predict_hazard <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.predict_hazard>`
 
         Examples
         --------
@@ -277,7 +314,7 @@ class PrescriptionLearner(SupervisedLearner):
         learner for each point in the features `X`.
 
         Julia Equivalent:
-        `IAI.predict_outcomes <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.predict_outcomes-Tuple%7BLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s60%22%2C2%7D%2520where%2520var%22%23s60%22%3C%3AReal%7D%7D>`
+        `IAI.predict_outcomes <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.predict_outcomes-Tuple%7BLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s60%22%2C2%7D%2520where%2520var%22%23s60%22%3C%3AReal%7D%7D>`
 
         Examples
         --------
@@ -290,11 +327,11 @@ class PolicyLearner(SupervisedLearner):
     """Abstract type encompassing all learners for policy tasks"""
 
     def predict_outcomes(self, *args, **kwargs):
-        """Return the outcome from `rewards` for point in the features `X`
+        """Return the outcome from `rewards` for each point in the features `X`
         under the prescriptions made by the learner.
 
         Julia Equivalent:
-        `IAI.predict_outcomes <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.predict_outcomes-Union%7BTuple%7BO%7D%2C%2520Tuple%7BLearner%7BIAIBase.PolicyTask%7BO%7D%7D%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s60%22%2C2%7D%2520where%2520var%22%23s60%22%3C%3AReal%7D%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s60%22%2C2%7D%2520where%2520var%22%23s60%22%3C%3AReal%7D%7D%7D%2520where%2520O>`
+        `IAI.predict_outcomes <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.predict_outcomes-Union%7BTuple%7BO%7D%2C%2520Tuple%7BLearner%7BIAIBase.PolicyTask%7BO%7D%7D%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s60%22%2C2%7D%2520where%2520var%22%23s60%22%3C%3AReal%7D%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s60%22%2C2%7D%2520where%2520var%22%23s60%22%3C%3AReal%7D%7D%7D%2520where%2520O>`
 
         Examples
         --------
@@ -307,12 +344,50 @@ class PolicyLearner(SupervisedLearner):
         _requires_iai_version("2.0.0", "predict_outcomes")
         return _IAI.predict_outcomes_convert(self._jl_obj, *args, **kwargs)
 
+    def predict_treatment_rank(self, *args, **kwargs):
+        """Return the treatments in ranked order of effectiveness for each
+        point in the features `X` as predicted by the learner.
+
+        Julia Equivalent:
+        `IAI.predict_treatment_rank <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.predict_treatment_rank>`
+
+        Examples
+        --------
+        >>> lnr.predict_treatment_rank(X)
+
+        Compatibility
+        -------------
+        Requires IAI version 2.1 or higher.
+        """
+        _requires_iai_version("2.1.0", "predict_treatment_rank")
+        return _np.array(_IAI.predict_treatment_rank_convert(self._jl_obj,
+                                                             *args, **kwargs))
+
+    def predict_treatment_outcome(self, *args, **kwargs):
+        """Return the estimated quality of each treatment in the trained model
+        of the learner for each point in the features `X`.
+
+        Julia Equivalent:
+        `IAI.predict_treatment_outcome <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.predict_treatment_outcome>`
+
+        Examples
+        --------
+        >>> lnr.predict_treatment_outcome(X)
+
+        Compatibility
+        -------------
+        Requires IAI version 2.1 or higher.
+        """
+        _requires_iai_version("2.1.0", "predict_treatment_outcome")
+        return _IAI.predict_treatment_outcome_convert(self._jl_obj, *args,
+                                                      **kwargs)
+
 
 class GridSearch(Learner):
     """Controls grid search over parameter combinations in `params` for `lnr`.
 
     Julia Equivalent:
-    `IAI.GridSearch <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.GridSearch>`
+    `IAI.GridSearch <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.GridSearch>`
 
     Examples
     --------
@@ -393,7 +468,7 @@ class GridSearch(Learner):
         the grid.
 
         Julia Equivalent:
-        `IAI.get_learner <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.get_learner>`
+        `IAI.get_learner <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.get_learner>`
 
         Examples
         --------
@@ -408,7 +483,7 @@ class GridSearch(Learner):
         """Return the best parameter combination from the grid.
 
         Julia Equivalent:
-        `IAI.get_best_params <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.get_best_params>`
+        `IAI.get_best_params <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.get_best_params>`
 
         Examples
         --------
@@ -420,7 +495,7 @@ class GridSearch(Learner):
         """Return a summary of the results from the grid search.
 
         Julia Equivalent:
-        `IAI.get_grid_results <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.get_grid_results>`
+        `IAI.get_grid_results <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.get_grid_results>`
 
         Examples
         --------
@@ -432,7 +507,7 @@ class GridSearch(Learner):
         """Fit a grid with data `X` and `y` using k-fold cross-validation.
 
         Julia Equivalent:
-        `IAI.fit_cv! <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.fit_cv!>`
+        `IAI.fit_cv! <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.fit_cv!>`
 
         Examples
         --------
@@ -441,7 +516,7 @@ class GridSearch(Learner):
         Parameters
         ----------
         Refer to the documentation on
-        `data preparation <https://docs.interpretable.ai/v2.0.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
+        `data preparation <https://docs.interpretable.ai/v2.1.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
         for information on how to format and supply the data.
         """
         _IAI.fit_cv_convert(self._jl_obj, *args, **kwargs)
@@ -452,7 +527,7 @@ class GridSearch(Learner):
         cross-validation and impute missing values in `X`.
 
         Julia Equivalent:
-        `IAI.fit_transform_cv! <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.fit_transform_cv!>`
+        `IAI.fit_transform_cv! <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.fit_transform_cv!>`
 
         Examples
         --------
@@ -461,7 +536,7 @@ class GridSearch(Learner):
         Parameters
         ----------
         Refer to the documentation on
-        `data preparation <https://docs.interpretable.ai/v2.0.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
+        `data preparation <https://docs.interpretable.ai/v2.1.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
         for information on how to format and supply the data.
         """
         self._check_delegate("fit_transform", "fit_transform_cv")
@@ -508,27 +583,21 @@ class GridSearch(Learner):
 
 
 class ROCCurve():
-    """Container for ROC curve information with the following fields:
-
-    - `coords`: a `dict` for each point on the curve with the following keys:
-        - `'fpr'`: false positive rate at the given threshold
-        - `'tpr'`: true positive rate at the given threshold
-        - `'threshold'`: the threshold
-    - `auc`: the area-under-the-curve (AUC)
+    """Container for ROC curve information.
 
     Julia Equivalent:
-    `IAI.ROCCurve <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.ROCCurve>`
+    `IAI.ROCCurve <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.ROCCurve>`
 
     Examples
     --------
     Construct an
-    `ROCCurve <https://docs.interpretable.ai/v2.0.0/IAI-Python/reference/#ROCCurve>`
+    `ROCCurve <https://docs.interpretable.ai/v2.1.0/IAI-Python/reference/#ROCCurve>`
     using trained `lnr` on the features `X` and labels `y`:
 
     >>> ROCCurve(lnr, X, y)
 
     Construct an
-    `ROCCurve <https://docs.interpretable.ai/v2.0.0/IAI-Python/reference/#ROCCurve>`
+    `ROCCurve <https://docs.interpretable.ai/v2.1.0/IAI-Python/reference/#ROCCurve>`
     using predicted probabilities `probs` and true labels `y`, with
     probabilities indicating chance of predicting `positive_label`:
 
@@ -562,7 +631,7 @@ class ROCCurve():
         `filename` as HTML.
 
         Julia Equivalent:
-        `IAI.write_html <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.write_html>`
+        `IAI.write_html <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.write_html>`
 
         Examples
         --------
@@ -579,7 +648,7 @@ class ROCCurve():
         """Visualize the ROC curve in the browser.
 
         Julia Equivalent:
-        `IAI.show_in_browser <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.show_in_browser>`
+        `IAI.show_in_browser <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.show_in_browser>`
 
         Examples
         --------
@@ -587,6 +656,28 @@ class ROCCurve():
         """
         return _IAI.show_in_browser_convert(self._jl_obj, **kwargs)
 
+    def get_data(self):
+        """Extract the underlying data from the curve as a `dict` with two keys:
+        - `coords`: a `dict` for each point on the curve with the following keys:
+            - `'fpr'`: false positive rate at the given threshold
+            - `'tpr'`: true positive rate at the given threshold
+            - `'threshold'`: the threshold
+        - `auc`: the area-under-the-curve (AUC)
+
+        Julia Equivalent:
+        `IAI.get_roc_curve_data <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.get_roc_curve_data>`
+
+        Examples
+        --------
+        >>> curve.get_data()
+
+        Compatibility
+        -------------
+        Requires IAI version 2.1 or higher.
+        """
+        _requires_iai_version("2.1.0", "get_data")
+        return _IAI.get_roc_curve_data_convert(self._jl_obj)
+
 
 class SurvivalCurve():
     """Container for survival curve information.
@@ -595,7 +686,7 @@ class SurvivalCurve():
     time `t`.
 
     Julia Equivalent:
-    `IAI.SurvivalCurve <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.SurvivalCurve>`
+    `IAI.SurvivalCurve <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.SurvivalCurve>`
     """
     def __init__(self, jl_curve):
         self._jl_obj = jl_curve
@@ -614,7 +705,7 @@ class SurvivalCurve():
         - `'coefs'`: the probablility for each breakpoint on the curve
 
         Julia Equivalent:
-        `IAI.get_survival_curve_data <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.get_survival_curve_data>`
+        `IAI.get_survival_curve_data <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.get_survival_curve_data>`
 
         Examples
         --------
