@@ -11,7 +11,7 @@ class TreeLearner(SupervisedLearner):
         """Return the number of nodes in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_num_nodes <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_num_nodes>`
+        `IAI.get_num_nodes <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_num_nodes>`
 
         Examples
         --------
@@ -23,7 +23,7 @@ class TreeLearner(SupervisedLearner):
         """Return `True` if node `node_index` in the trained learner is a leaf.
 
         Julia Equivalent:
-        `IAI.is_leaf <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.is_leaf>`
+        `IAI.is_leaf <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.is_leaf>`
 
         Examples
         --------
@@ -35,7 +35,7 @@ class TreeLearner(SupervisedLearner):
         """Return the depth of node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_depth <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_depth>`
+        `IAI.get_depth <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_depth>`
 
         Examples
         --------
@@ -48,7 +48,7 @@ class TreeLearner(SupervisedLearner):
         in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_num_samples <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_num_samples>`
+        `IAI.get_num_samples <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_num_samples>`
 
         Examples
         --------
@@ -61,7 +61,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_lower_child <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_lower_child>`
+        `IAI.get_lower_child <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_lower_child>`
 
         Examples
         --------
@@ -74,7 +74,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_parent <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_parent>`
+        `IAI.get_parent <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_parent>`
 
         Examples
         --------
@@ -87,7 +87,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_upper_child <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_upper_child>`
+        `IAI.get_upper_child <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_upper_child>`
 
         Examples
         --------
@@ -100,7 +100,7 @@ class TreeLearner(SupervisedLearner):
         parallel split.
 
         Julia Equivalent:
-        `IAI.is_parallel_split <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.is_parallel_split>`
+        `IAI.is_parallel_split <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.is_parallel_split>`
 
         Examples
         --------
@@ -113,7 +113,7 @@ class TreeLearner(SupervisedLearner):
         hyperplane split.
 
         Julia Equivalent:
-        `IAI.is_hyperplane_split <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.is_hyperplane_split>`
+        `IAI.is_hyperplane_split <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.is_hyperplane_split>`
 
         Examples
         --------
@@ -126,7 +126,7 @@ class TreeLearner(SupervisedLearner):
         categoric split.
 
         Julia Equivalent:
-        `IAI.is_categoric_split <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.is_categoric_split>`
+        `IAI.is_categoric_split <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.is_categoric_split>`
 
         Examples
         --------
@@ -139,7 +139,7 @@ class TreeLearner(SupervisedLearner):
         ordinal split.
 
         Julia Equivalent:
-        `IAI.is_ordinal_split <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.is_ordinal_split>`
+        `IAI.is_ordinal_split <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.is_ordinal_split>`
 
         Examples
         --------
@@ -152,7 +152,7 @@ class TreeLearner(SupervisedLearner):
         categoric/parallel split.
 
         Julia Equivalent:
-        `IAI.is_mixed_parallel_split <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.is_mixed_parallel_split>`
+        `IAI.is_mixed_parallel_split <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.is_mixed_parallel_split>`
 
         Examples
         --------
@@ -165,7 +165,7 @@ class TreeLearner(SupervisedLearner):
         categoric/ordinal split.
 
         Julia Equivalent:
-        `IAI.is_mixed_ordinal_split <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.is_mixed_ordinal_split>`
+        `IAI.is_mixed_ordinal_split <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.is_mixed_ordinal_split>`
 
         Examples
         --------
@@ -178,7 +178,7 @@ class TreeLearner(SupervisedLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.missing_goes_lower <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.missing_goes_lower>`
+        `IAI.missing_goes_lower <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.missing_goes_lower>`
 
         Examples
         --------
@@ -191,7 +191,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_feature <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_split_feature>`
+        `IAI.get_split_feature <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_split_feature>`
 
         Examples
         --------
@@ -204,7 +204,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_threshold <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_split_threshold>`
+        `IAI.get_split_threshold <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_split_threshold>`
 
         Examples
         --------
@@ -217,7 +217,7 @@ class TreeLearner(SupervisedLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_categories <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_split_categories>`
+        `IAI.get_split_categories <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_split_categories>`
 
         Examples
         --------
@@ -230,7 +230,7 @@ class TreeLearner(SupervisedLearner):
         hyperplane split at  node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_weights <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_split_weights>`
+        `IAI.get_split_weights <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_split_weights>`
 
         Examples
         --------
@@ -243,7 +243,7 @@ class TreeLearner(SupervisedLearner):
         features `X` falls.
 
         Julia Equivalent:
-        `IAI.apply <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.apply>`
+        `IAI.apply <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.apply>`
 
         Examples
         --------
@@ -256,20 +256,21 @@ class TreeLearner(SupervisedLearner):
         each node in the learner.
 
         Julia Equivalent:
-        `IAI.apply_nodes <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.apply_nodes>`
+        `IAI.apply_nodes <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.apply_nodes>`
 
         Examples
         --------
         >>> lnr.apply_nodes(X)
         """
-        return _IAI.apply_nodes_convert(self._jl_obj, *args, **kwargs)
+        node_inds = _IAI.apply_nodes_convert(self._jl_obj, *args, **kwargs)
+        return [inds - 1 for inds in node_inds]
 
     def decision_path(self, *args, **kwargs):
         """Return a matrix where entry `(i, j)` is `True` if the `i`th point in
         the features `X` passes through the `j`th node in the learner.
 
         Julia Equivalent:
-        `IAI.decision_path <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.decision_path>`
+        `IAI.decision_path <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.decision_path>`
 
         Examples
         --------
@@ -282,7 +283,7 @@ class TreeLearner(SupervisedLearner):
         features `X`.
 
         Julia Equivalent:
-        `IAI.print_path <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.print_path>`
+        `IAI.print_path <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.print_path>`
 
         Examples
         --------
@@ -298,7 +299,7 @@ class TreeLearner(SupervisedLearner):
         be installed and on the system `PATH`.
 
         Julia Equivalent:
-        `IAI.write_png <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.write_png>`
+        `IAI.write_png <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.write_png>`
 
         Examples
         --------
@@ -314,7 +315,7 @@ class TreeLearner(SupervisedLearner):
         be installed and on the system `PATH`.
 
         Julia Equivalent:
-        `IAI.write_pdf <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.write_pdf>`
+        `IAI.write_pdf <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.write_pdf>`
 
         Compatibility
         -------------
@@ -335,7 +336,7 @@ class TreeLearner(SupervisedLearner):
         be installed and on the system `PATH`.
 
         Julia Equivalent:
-        `IAI.write_svg <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.write_svg>`
+        `IAI.write_svg <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.write_svg>`
 
         Compatibility
         -------------
@@ -353,7 +354,7 @@ class TreeLearner(SupervisedLearner):
         [.dot format](http://www.graphviz.org/content/dot-language/).
 
         Julia Equivalent:
-        `IAI.write_dot <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.write_dot>`
+        `IAI.write_dot <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.write_dot>`
 
         Examples
         --------
@@ -366,7 +367,7 @@ class TreeLearner(SupervisedLearner):
         HTML.
 
         Julia Equivalent:
-        `IAI.write_html <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.write_html>`
+        `IAI.write_html <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.write_html>`
 
         Examples
         --------
@@ -378,7 +379,7 @@ class TreeLearner(SupervisedLearner):
         """Show interactive visualization of learner in default browser.
 
         Julia Equivalent:
-        `IAI.show_in_browser <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.show_in_browser>`
+        `IAI.show_in_browser <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.show_in_browser>`
 
         Examples
         --------
@@ -391,7 +392,7 @@ class TreeLearner(SupervisedLearner):
         HTML.
 
         Julia Equivalent:
-        `IAI.write_questionnaire <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.write_questionnaire>`
+        `IAI.write_questionnaire <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.write_questionnaire>`
 
         Examples
         --------
@@ -404,7 +405,7 @@ class TreeLearner(SupervisedLearner):
         """Show interactive questionnaire based on learner in default browser.
 
         Julia Equivalent:
-        `IAI.show_questionnaire <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.show_questionnaire>`
+        `IAI.show_questionnaire <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.show_questionnaire>`
 
         Examples
         --------
@@ -418,31 +419,33 @@ class ClassificationTreeLearner(ClassificationLearner):
     leaves.
     """
 
-    def get_classification_label(self, node_index):
+    def get_classification_label(self, node_index, **kwargs):
         """Return the predicted label at node `node_index` in the trained
         learner.
 
         Julia Equivalent:
-        `IAI.get_classification_label <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_classification_label>`
+        `IAI.get_classification_label <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_classification_label>`
 
         Examples
         --------
         >>> lnr.get_classification_label(node_index)
         """
-        return _IAI.get_classification_label_convert(self._jl_obj, node_index)
+        return _IAI.get_classification_label_convert(self._jl_obj, node_index,
+                                                     **kwargs)
 
-    def get_classification_proba(self, node_index):
+    def get_classification_proba(self, node_index, **kwargs):
         """Return the predicted probabilities of class membership at node
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_classification_proba <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_classification_proba>`
+        `IAI.get_classification_proba <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_classification_proba>`
 
         Examples
         --------
         >>> lnr.get_classification_proba(node_index)
         """
-        return _IAI.get_classification_proba_convert(self._jl_obj, node_index)
+        return _IAI.get_classification_proba_convert(self._jl_obj, node_index,
+                                                     **kwargs)
 
     def set_threshold(self, *args, **kwargs):
         """For a binary classification problem, update the the predicted labels
@@ -451,7 +454,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         will be simplified after all changes have been made.
 
         Julia Equivalent:
-        `IAI.set_threshold! <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.set_threshold!>`
+        `IAI.set_threshold! <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.set_threshold!>`
 
         Examples
         --------
@@ -464,7 +467,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         """Show the probability of `display_label` when visualizing learner.
 
         Julia Equivalent:
-        `IAI.set_display_label! <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.set_display_label!>`
+        `IAI.set_display_label! <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.set_display_label!>`
 
         Examples
         --------
@@ -478,7 +481,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         predicted label when visualizing learner.
 
         Julia Equivalent:
-        `IAI.reset_display_label! <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.reset_display_label!>`
+        `IAI.reset_display_label! <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.reset_display_label!>`
 
         Examples
         --------
@@ -493,111 +496,153 @@ class RegressionTreeLearner(RegressionLearner):
     leaves.
     """
 
-    def get_regression_constant(self, node_index):
+    def get_regression_constant(self, node_index, **kwargs):
         """Return the constant term in the regression prediction at node
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_constant <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.RegressionTask%7D%2CInt64%7D>`
+        `IAI.get_regression_constant <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.RegressionTask%7D%2CInt64%7D>`
 
         Examples
         --------
         >>> lnr.get_regression_constant(node_index)
         """
-        return _IAI.get_regression_constant_convert(self._jl_obj, node_index)
+        return _IAI.get_regression_constant_convert(self._jl_obj, node_index,
+                                                    **kwargs)
 
-    def get_regression_weights(self, node_index):
+    def get_regression_weights(self, node_index, **kwargs):
         """Return the weights for each feature in the regression prediction at
         node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_weights <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.RegressionTask%7D%2CInt64%7D>`
+        `IAI.get_regression_weights <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.RegressionTask%7D%2CInt64%7D>`
 
         Examples
         --------
         >>> lnr.get_regression_weights(node_index)
         """
-        return _IAI.get_regression_weights_convert(self._jl_obj, node_index)
+        return _IAI.get_regression_weights_convert(self._jl_obj, node_index,
+                                                   **kwargs)
 
 
 class SurvivalTreeLearner(SurvivalLearner):
     """Abstract type encompassing all tree-based learners with survival leaves.
     """
 
-    def get_survival_curve(self, node_index):
+    def get_survival_curve(self, node_index, **kwargs):
         """Return the
-        `SurvivalCurve <https://docs.interpretable.ai/v2.0.0/IAI-Python/reference/#SurvivalCurve>`
+        `SurvivalCurve <https://docs.interpretable.ai/v2.1.0/IAI-Python/reference/#SurvivalCurve>`
         at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_survival_curve <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_survival_curve>`
+        `IAI.get_survival_curve <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_survival_curve>`
 
         Examples
         --------
         >>> lnr.get_survival_curve(node_index)
         """
-        jl_curve = _IAI.get_survival_curve_convert(self._jl_obj, node_index)
+        jl_curve = _IAI.get_survival_curve_convert(self._jl_obj, node_index,
+                                                   **kwargs)
         return SurvivalCurve(jl_curve)
 
+    def get_survival_expected_time(self, node_index, **kwargs):
+        """Return the predicted expected survival time at node `node_index` in
+        the trained learner.
+
+        Julia Equivalent:
+        `IAI.get_survival_expected_time <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_survival_expected_time>`
+
+        Examples
+        --------
+        >>> lnr.get_survival_expected_time(node_index)
+
+        Compatibility
+        -------------
+        Requires IAI version 2.1 or higher.
+        """
+        _requires_iai_version("2.1.0", "get_survival_expected_time")
+        return _IAI.get_survival_expected_time_convert(self._jl_obj,
+                                                       node_index, **kwargs)
+
+    def get_survival_hazard(self, node_index, **kwargs):
+        """Return the predicted hazard ratio at node `node_index` in the
+        trained learner.
+
+        Julia Equivalent:
+        `IAI.get_survival_hazard <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_survival_hazard>`
+
+        Examples
+        --------
+        >>> lnr.get_survival_hazard(node_index)
+
+        Compatibility
+        -------------
+        Requires IAI version 2.1 or higher.
+        """
+        _requires_iai_version("2.1.0", "get_survival_hazard")
+        return _IAI.get_survival_hazard_convert(self._jl_obj, node_index,
+                                                **kwargs)
+
 
 class PrescriptionTreeLearner(PrescriptionLearner):
     """Abstract type encompassing all tree-based learners with prescription
     leaves.
     """
 
-    def get_prescription_treatment_rank(self, node_index):
+    def get_prescription_treatment_rank(self, node_index, **kwargs):
         """Return the treatments ordered from most effective to least effective
         at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_prescription_treatment_rank <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_prescription_treatment_rank>`
+        `IAI.get_prescription_treatment_rank <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_prescription_treatment_rank>`
 
         Examples
         --------
         >>> lnr.get_prescription_treatment_rank(node_index)
         """
         return _IAI.get_prescription_treatment_rank_convert(self._jl_obj,
-                                                            node_index)
+                                                            node_index,
+                                                            **kwargs)
 
-    def get_regression_constant(self, node_index, treatment):
+    def get_regression_constant(self, node_index, treatment, **kwargs):
         """Return the constant in the regression prediction for `treatment` at
         node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_constant <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CInt64%2CAny%7D>`
+        `IAI.get_regression_constant <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CInt64%2CAny%7D>`
 
         Examples
         --------
         >>> lnr.get_regression_constant(node_index, treatment)
         """
         return _IAI.get_regression_constant_convert(self._jl_obj, node_index,
-                                                    treatment)
+                                                    treatment, **kwargs)
 
-    def get_regression_weights(self, node_index, treatment):
+    def get_regression_weights(self, node_index, treatment, **kwargs):
         """Return the weights for each feature in the regression prediction for
         `treatment` at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_weights <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CInt64%2CAny%7D>`
+        `IAI.get_regression_weights <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CInt64%2CAny%7D>`
 
         Examples
         --------
         >>> lnr.get_regression_weights(node_index, treatment)
         """
         return _IAI.get_regression_weights_convert(self._jl_obj, node_index,
-                                                   treatment)
+                                                   treatment, **kwargs)
 
 
 class PolicyTreeLearner(PolicyLearner):
     """Abstract type encompassing all tree-based learners with policy leaves.
     """
 
-    def get_policy_treatment_rank(self, node_index):
+    def get_policy_treatment_rank(self, node_index, **kwargs):
         """Return the treatments ordered from most effective to least effective
         at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_policy_treatment_rank <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.get_policy_treatment_rank>`
+        `IAI.get_policy_treatment_rank <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_policy_treatment_rank>`
 
         Examples
         --------
@@ -608,7 +653,27 @@ class PolicyTreeLearner(PolicyLearner):
         Requires IAI version 2.0 or higher.
         """
         _requires_iai_version("2.0.0", "get_policy_treatment_rank")
-        return _IAI.get_policy_treatment_rank_convert(self._jl_obj, node_index)
+        return _IAI.get_policy_treatment_rank_convert(self._jl_obj, node_index,
+                                                      **kwargs)
+
+    def get_policy_treatment_outcome(self, node_index, **kwargs):
+        """Return the quality of the treatments at node `node_index` in the
+        trained learner.
+
+        Julia Equivalent:
+        `IAI.get_policy_treatment_outcome <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.get_policy_treatment_outcome>`
+
+        Examples
+        --------
+        >>> lnr.get_policy_treatment_outcome(node_index)
+
+        Compatibility
+        -------------
+        Requires IAI version 2.1 or higher.
+        """
+        _requires_iai_version("2.1.0", "get_policy_treatment_outcome")
+        return _IAI.get_policy_treatment_outcome_convert(self._jl_obj,
+                                                         node_index, **kwargs)
 
 
 class AbstractVisualization():
@@ -626,7 +691,7 @@ class AbstractVisualization():
         """Write interactive browser visualization to `filename` as HTML.
 
         Julia Equivalent:
-        `IAI.write_html <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.write_html>`
+        `IAI.write_html <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.write_html>`
 
         Examples
         --------
@@ -638,7 +703,7 @@ class AbstractVisualization():
         """Show interactive visualization in default browser.
 
         Julia Equivalent:
-        `IAI.show_in_browser <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.show_in_browser>`
+        `IAI.show_in_browser <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.show_in_browser>`
 
         Examples
         --------
@@ -651,7 +716,7 @@ class TreePlot(AbstractVisualization):
     """Specify an interactive tree visualization of `lnr`.
 
     Julia Equivalent:
-    `IAI.TreePlot <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.TreePlot>`
+    `IAI.TreePlot <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.TreePlot>`
 
     Examples
     --------
@@ -660,7 +725,7 @@ class TreePlot(AbstractVisualization):
     Parameters
     ----------
     Refer to the
-    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v2.0.0/IAITrees/advanced/#Advanced-Visualization-1>`
+    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v2.1.0/IAITrees/advanced/#Advanced-Visualization-1>`
     for available parameters.
 
     Compatibility
@@ -677,7 +742,7 @@ class Questionnaire(AbstractVisualization):
     """Specify an interactive questionnaire of `lnr`.
 
     Julia Equivalent:
-    `IAI.Questionnaire <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.Questionnaire>`
+    `IAI.Questionnaire <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.Questionnaire>`
 
     Examples
     --------
@@ -687,7 +752,7 @@ class Questionnaire(AbstractVisualization):
     ----------
 
     Refer to the
-    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v2.0.0/IAITrees/advanced/#Advanced-Visualization-1>`
+    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v2.1.0/IAITrees/advanced/#Advanced-Visualization-1>`
     for available parameters.
 
     Compatibility
@@ -704,13 +769,13 @@ class MultiQuestionnaire(AbstractVisualization):
     """Specify an interactive questionnaire of multiple tree learners
 
     Julia Equivalent:
-    `IAI.MultiQuestionnaire <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.MultiQuestionnaire>`
+    `IAI.MultiQuestionnaire <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.MultiQuestionnaire>`
 
     Examples
     --------
     Constructs an interactive questionnaire using multiple tree learners from
     specified questions. Refer to the
-    `documentation on advanced tree visualization <https://docs.interpretable.ai/v2.0.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
+    `documentation on advanced tree visualization <https://docs.interpretable.ai/v2.1.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
     for more information.
 
     >>> MultiQuestionnaire(questions)
@@ -741,13 +806,13 @@ class MultiTreePlot(AbstractVisualization):
     """Specify an interactive tree visualization of multiple tree learners
 
     Julia Equivalent:
-    `IAI.MultiTreePlot <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.MultiTreePlot>`
+    `IAI.MultiTreePlot <https://docs.interpretable.ai/v2.1.0/IAITrees/reference/#IAI.MultiTreePlot>`
 
     Examples
     --------
     Constructs an interactive tree visualization using multiple tree learners
     from specified questions. Refer to the
-    `documentation on advanced tree visualization <https://docs.interpretable.ai/v2.0.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
+    `documentation on advanced tree visualization <https://docs.interpretable.ai/v2.1.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
     for more information.
 
     >>> MultiTreePlot(questions)
